pub struct ConfigOptions {
pub compiler: Option<String>,
pub compile_flags_txt: Option<Vec<String>>,
pub diagnostics: Option<bool>,
pub default_diagnostics: Option<bool>,
}Fields
compiler: Option<String>compile_flags_txt: Option<Vec<String>>diagnostics: Option<bool>default_diagnostics: Option<bool>Trait Implementations
Sourceimpl Clone for ConfigOptions
impl Clone for ConfigOptions
Sourcefn clone(&self) -> ConfigOptions
fn clone(&self) -> ConfigOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigOptions
impl Debug for ConfigOptions
Sourceimpl Default for ConfigOptions
impl Default for ConfigOptions
Sourceimpl<'de> Deserialize<'de> for ConfigOptions
impl<'de> Deserialize<'de> for ConfigOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigOptions
impl JsonSchema for ConfigOptions
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigOptions
impl PartialEq for ConfigOptions
Sourceimpl Serialize for ConfigOptions
impl Serialize for ConfigOptions
impl Eq for ConfigOptions
impl StructuralPartialEq for ConfigOptions