pub struct ProjectConfig {
pub path: PathBuf,
pub config: Config,
}Fields
path: PathBufconfig: ConfigConfig for this project. If path is a directory, applies to all files
and subdirectories. If path is a file, just applies to that file