pub struct RootConfig {
pub default_config: Option<Config>,
pub projects: Option<Vec<ProjectConfig>>,
}Fields
default_config: Option<Config>projects: Option<Vec<ProjectConfig>>Implementations
Sourceimpl RootConfig
impl RootConfig
Sourcepub fn get_project<'a>(
&'a self,
request_path: &PathBuf,
) -> Option<&'a ProjectConfig>
pub fn get_project<'a>( &'a self, request_path: &PathBuf, ) -> Option<&'a ProjectConfig>
Sourcepub fn get_config<'a>(&'a self, req_uri: &'a Uri) -> &'a Config
pub fn get_config<'a>(&'a self, req_uri: &'a Uri) -> &'a Config
Returns the project-specific Config associated with uri, or the default if no
matching configuration is found
Panics
Will panic if self does not have a valid configuration for req_uri, meaning
no default config and no applicable project config
Sourcepub fn effective_arches(&self) -> Vec<Arch>
pub fn effective_arches(&self) -> Vec<Arch>
Panics
Will panic if self.default_config is None
Sourcepub fn effective_assemblers(&self) -> Vec<Assembler>
pub fn effective_assemblers(&self) -> Vec<Assembler>
Panics
Will panic if self.default_config is None
pub fn is_isa_enabled(&self, isa: Arch) -> bool
pub fn is_assembler_enabled(&self, assembler: Assembler) -> bool