pub struct ServerStore {
pub names_to_info: NameToInfoMaps,
pub completion_items: CompletionItems,
pub compile_commands: CompilationDatabase,
pub include_dirs: HashMap<SourceFile, Vec<PathBuf>>,
}Expand description
Struct to store all documentation the server uses to service user requests
Fields
names_to_info: NameToInfoMapsLinks names of instructions, registers, and directives to their documentation
completion_items: CompletionItemsCompletion items for instructions, registers, and directives
compile_commands: CompilationDatabaseCompilation database loaded from compile_commands.json or compile_flags.txt
include_dirs: HashMap<SourceFile, Vec<PathBuf>>Include directories